//---------------------------------------------------------------------------
// File: TMainForm.h
//
//  TDx_Sound_Library
//  Example7 - Streaming Sounds or Music
//
// Date: 21st June, 2002
// Author: Darren John Dwyer
// Copyright: (c) 2002 Darren John Dwyer, All Rights Reserved.
//
// Description:
//
// This example "Streams" sound effects by creating a tiny buffer,
// then loading part of the music into the buffer whilst simultaneously
// playing another section of the buffer.
//
//---------------------------------------------------------------------------
#ifndef TMainFormH
#define TMainFormH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include "TDx_Sound.h"
#include "TDx_SoundBuffer.h"
#include "TDSBufferDesc.h"
#include "TDSCaps.h"
#include <vcl\ExtCtrls.hpp>
#include <vcl\FileCtrl.hpp>
#include "TDx_SoundNotify.h"
#include "TDSBPositionNotify.h"
#include <vcl\Dialogs.hpp>
//---------------------------------------------------------------------------
#define MAX_DEVICES 256
//---------------------------------------------------------------------------
class TMainForm : public TForm
{
__published:    // IDE-managed Components
    TListBox *DevicesListBox;
    TLabel *Label3;
    TDx_Sound *Dx_Sound1;
    TDx_SoundBuffer *Dx_SoundBuffer1;
    TDSBufferDesc *DSBufferDesc1;
    TBitBtn *QuitButton;
    TPanel *Panel1;
    TLabel *Label23;
    TFileListBox *FileListBox1;
    TLabel *Label2;
    TDriveComboBox *DriveComboBox1;
    TDirectoryListBox *DirectoryListBox1;
    TEdit *Edit1;
    TBitBtn *PlayButton;
    TPanel *Panel2;
    TLabel *PlayingLabel;
    TLabel *PlayChunkLabel;
    TLabel *BufferSizeLabel;
    TLabel *NotCreatedLabel;
    TDx_SoundNotify *Dx_SoundNotify1;
    TDSBPositionNotify *DSBPositionNotify1;
    TMemo *StatusMemo;
    TLabel *NotificationLabel;
    TLabel *StatusLabel;
    TBitBtn *ClearButton;
    TLabel *BytesReadLabel;
    TLabel *FileSizeLabel;
    TLabel *LoadChunkLabel;
    TLabel *FileNameLabel;
    TLabel *BytesToLoadLabel;
    TLabel *Label1;
    TLabel *Label4;
    TLabel *Label5;
    TLabel *Label6;
    TBitBtn *StopButton;
    TBitBtn *ToggleButton;
    void __fastcall Dx_SoundBuffer1BufferLost(TObject *Sender);
    void __fastcall Dx_Sound1Destroy(TObject *Sender);
    void __fastcall FormDestroy(TObject *Sender);
    void __fastcall FormCreate(TObject *Sender);
    void __fastcall DevicesListBoxClick(TObject *Sender);
    void __fastcall PlayButtonClick(TObject *Sender);
    void __fastcall Dx_SoundBuffer1Create(TObject *Sender);
    void __fastcall Dx_SoundBuffer1Destroy(TObject *Sender);
    void __fastcall FileListBox1DblClick(TObject *Sender);
    void __fastcall StopButtonClick(TObject *Sender);
    void __fastcall QuitButtonClick(TObject *Sender);
    void __fastcall Dx_SoundNotify1Notify(TObject *Sender, int Value);
    void __fastcall Dx_SoundNotify1Create(TObject *Sender);
    void __fastcall Dx_SoundNotify1Destroy(TObject *Sender);
    void __fastcall ToggleButtonClick(TObject *Sender);
    void __fastcall ClearButtonClick(TObject *Sender);

    void __fastcall Dx_Sound1Create(TObject *Sender);
    void __fastcall Dx_Sound1DSEnumerate(TObject *Sender, GUID *Guid,
          AnsiString DriverDescription, AnsiString DriverModule,
          void *Context, bool &Finished);
    void __fastcall Dx_Sound1Error(TObject *Sender, AnsiString Function,
          AnsiString Error, AnsiString ErrorMessage);
    void __fastcall Dx_SoundBuffer1Error(TObject *Sender,
          AnsiString Function, AnsiString Error, AnsiString ErrorMessage);
    void __fastcall DSBufferDesc1Error(TObject *Sender,
          AnsiString Function, AnsiString Error, AnsiString ErrorMessage);
    void __fastcall Dx_SoundNotify1Error(TObject *Sender,
          AnsiString Function, AnsiString Error, AnsiString ErrorMessage);
    void __fastcall DSBPositionNotify1Error(TObject *Sender,
          AnsiString Function, AnsiString Error, AnsiString ErrorMessage);
    void __fastcall DSBPositionNotify1Notify(TObject *Sender,
          int Notification);

private:    // User declarations

    TStringList*    Devices;
    TStringList*    Modules;
    TList*            Guids;

    AnsiString        LastFileName;

    WAVEFORMATEX    StreamFormat;

    dword           BytesRead;
    dword           BytesToLoad;

    bool            StopOnFirst;
    bool            StopOnSecond;
    bool            FinishedPlaying;

     void __fastcall PreloadFirstChunk();
    void __fastcall LoadFirstChunk();
    void __fastcall LoadSecondChunk();
    void __fastcall StopStreaming();

public:        // User declarations
    __fastcall TMainForm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern TMainForm *MainForm;
//---------------------------------------------------------------------------
#endif
